ScopeRequirementsGrants class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ScopeRequirementsGrants({required ScopeRequirements userGranted, required ScopeRequirements userDenied})
ScopeRequirementsGrants.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDenied ↔ ScopeRequirements
getter/setter pair
userGranted ↔ ScopeRequirements
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited