UserService class abstract
- Annotations
-
- @ChopperApi.new()
Constructors
Properties
- client ↔ ChopperClient
-
getter/setter pairinherited
- definitionType → Type
-
Used internally to retrieve the service from
ChopperClient.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deregisterProvider(
String userId, String provider) → Future< Response< DeregisterProviderResponse> > -
getUser(
String userId) → Future< Response< User> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patchUser(
String userId, {String? fallbackTimeZone}) → Future< Response< NoContent> > -
refreshUser(
String userId) → Future< Response< RefreshResponse> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
Client httpClient, Uri baseUrl, RequestInterceptor authInterceptor) → UserService