WorkoutService class abstract

Annotations
  • @ChopperApi.new()

Constructors

WorkoutService()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType → Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getWorkouts(String userId, DateTime startDate, {DateTime? endDate, String? provider}) → Future<Response<WorkoutsResponse>>
getWorkoutsRaw(String userId, DateTime startDate, DateTime? endDate, String? provider) → Future<Response<Object>>
getWorkoutStream(String workoutId) → Future<Response<WorkoutStreamResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(Client httpClient, Uri baseUrl, RequestInterceptor authInterceptor) → WorkoutService